@@ -42,138 +42,200 @@ $(document).on('shiny:sessioninitialized', function(event) {
     useShinyjs(),
     theme = shinytheme("readable"),
 
-    ####################################################################################
-    tags$head(tags$style(
-      type="text/css",
-      "#image0 img {max-width: 100%; width: auto; height: 100%; align: center}"
-    )),
-
-    tags$head(tags$style(
-      type="text/css",
-      "#image1 img {max-width: 100%; width: auto; height: 100%; align: center}"
-    )),
-
-    tags$head(tags$style(
-      type="text/css",
-      "#image2 img {max-width: 100%; width: auto; height: 100%; align: center}"
-    )),
-
-    tags$head(tags$style(
-      type="text/css",
-      "#image3 img {max-width: 100%; width: auto; height: 100%; align: center}"
-    )),
-
-    tags$head(tags$style(
-      type="text/css",
-      "#image4 img {max-width: 100%; width: auto; height: 100%; align: center}"
-    )),
-
-    tags$head(tags$style(
-      type="text/css",
-      "#image5 img {max-width: 100%; width: auto; height: 100%; align: center}"
-    )),
-
-    tags$head(tags$style(
-      type="text/css",
-      "#image6 img {max-width: 100%; width: auto; height: 100%; align: center}"
-    )),
-    ###################################################################################
-
-    tags$style(HTML("#a{color:darkblue; font-family:Lucida Arial ;font-size: 16px;
-             font-style: oblique;text-align:center}")), #tabs#
-
-    tags$style(HTML("#ab{color:darkblue; font-family:Lucida Arial ;font-size: 20px;
-             font-style: oblique;text-align:center}")), # widgets#
-
-    tags$style(HTML("#b{color:darkblue; font-family: cursive;font-size: 15px;
-            font-style: oblique;text-align:center}")), # download #
-    ####################################################################################
-
-    ## POP UP ##
-
-    bsTooltip(
-      id = "text1",
-      title = "Only a small part of the data is presented",
-      placement = "bottom",
-      trigger = "hover"
-    ),
-    bsTooltip(
-      id = "rotation",
-      title = "If the correlation between factors is low,choose varimax method",
-      placement = "bottom",
-      trigger = "hover"
-    ),
-    bsTooltip(
-      id = "factornumber",
-      title = "Determine the number of factors according to the result of the parallel analysis",
-      placement = "bottom",
-      trigger = "hover"
-    ),
-    bsTooltip(
-      id = "scree_plot",
-      title = "You can determine the number of eigen values over the black parallel analysis line as the number of factors",
-      placement = "top",
-      trigger = "hover"
-    ),
-    bsTooltip(
-      id = "eigen_value",
-      title = "Eigen values higher than the pa mean are indicated in red and underlined",
-      placement = "top",
-      trigger = "hover"
-    ),
-    bsTooltip(
-      id = "fakor",
-      title = "When the number of factors is more than 2 in order to see all the results slide the bar below to the right.",
-      placement = "bottom",
-      trigger = "hover"
-    ),
-    bsTooltip(
-      id = "type",
-      title = "Make sure you choose the data type correctly!",
-      placement = "top",
-      trigger = "hover"
-    ),
-    bsTooltip(
-      id = "tableFactor",
-      title = "Items with a lower factor loading than the determined cutting score are indicated in red and underlined",
-      placement = "top",
-      trigger = "hover"
-    ),
-
-    bsTooltip(
-      id = "KMo",
-      title = "You can examine the change in the KMO value when the items are removed or added.",
-      placement = "bottom",
-      trigger = "hover"
-    ),
-
-    ## TITLE PANEL - SIDE BAR PANEL ##
-
-    # titlePanel("PRINCIPAL COMPONENT ANALYSIS",
-    #   windowTitle = "PRINCIPAL COMPONENT ANALYSIS"
+    # setBackgroundColor(
+    #   color = c("white", "gray"),
+    #   gradient = "linear",
+    #   direction = c("bottom", "right")
     # ),
 
-    h1(id="title", "PRINCIPAL COMPONENT ANALYSIS"),
-    tags$style(HTML("#title{color: blue; font-family: Arial;font-size: 35px;
-            font-style: oblique;text-align:left}")),
+    uiOutput("cols"),
 
+    ####################################################################################
+    tags$head(tags$style(
+      type="text/css",
+      "#image0 img {max-width: 100%; width: auto; height: 100%; align: center}
+
+table,img, .tippy-content{ border-collapse: collapse;
+
+  border-radius: 1em;
+
+  overflow: hidden;}
+
+  th, td {
+
+  padding: 1em;
+
+  background: #ddd;
+
+  border-bottom: 2px solid white;
+
+  border-top: 2px solid white;
+
+  }
+
+ #tepe{
+  border-bottom: 3px solid black;
+  }
+
+      "
+    )),
+
+tags$head(tags$style(
+  type="text/css",
+  "#image1 img {max-width: 100%; width: auto; height: 100%; align: center}"
+)),
+
+tags$head(tags$style(
+  type="text/css",
+  "#image2 img {max-width: 100%; width: auto; height: 100%; align: center}"
+)),
+
+tags$head(tags$style(
+  type="text/css",
+  "#image3 img {max-width: 100%; width: auto; height: 100%; align: center}"
+)),
+
+tags$head(tags$style(
+  type="text/css",
+  "#image4 img {max-width: 100%; width: auto; height: 100%; align: center}"
+)),
+
+tags$head(tags$style(
+  type="text/css",
+  "#image5 img {max-width: 100%; width: auto; height: 100%; align: center}"
+)),
+
+tags$head(tags$style(
+  type="text/css",
+  "#image6 img {max-width: 100%; width: auto; height: 100%; align: center}"
+)),
+###################################################################################
+
+tags$style(HTML("#a{color:black; font-family:Lucida Arial ;font-size: 16px;
+              font-style: oblique;text-align:center}")), #tabs#
+
+tags$style(HTML("#ab{color:black; font-family:Lucida Arial ;font-size: 20px;
+             font-style: oblique;text-align:center}")), # widgets#
+
+tags$style(HTML("#b{color:black; font-family: cursive;font-size: 15px;
+            font-style: oblique;text-align:center}")), # download #
+####################################################################################
+
+## POP UP ##
+
+bsTooltip(
+  id = "text1",
+  title = "Only a small part of the data is presented",
+  placement = "bottom",
+  trigger = "hover"
+),
+bsTooltip(
+  id = "rotation",
+  title = "If the correlation between factors is low,choose varimax method",
+  placement = "bottom",
+  trigger = "hover"
+),
+bsTooltip(
+  id = "factornumber",
+  title = "Determine the number of factors according to the result of the parallel analysis",
+  placement = "bottom",
+  trigger = "hover"
+),
+bsTooltip(
+  id = "scree_plot",
+  title = "You can determine the number of eigen values over the black parallel analysis line as the number of factors",
+  placement = "top",
+  trigger = "hover"
+),
+bsTooltip(
+  id = "eigen_value",
+  title = "Eigen values higher than the pa mean are indicated in red and underlined",
+  placement = "top",
+  trigger = "hover"
+),
+bsTooltip(
+  id = "fakor",
+  title = "When the number of factors is more than 2 in order to see all the results slide the bar below to the right.",
+  placement = "bottom",
+  trigger = "hover"
+),
+bsTooltip(
+  id = "type",
+  title = "Make sure you choose the data type correctly!",
+  placement = "top",
+  trigger = "hover"
+),
+bsTooltip(
+  id = "tableFactor",
+  title = "Items with a lower factor loading than the determined cutting score are indicated in red and underlined",
+  placement = "top",
+  trigger = "hover"
+),
+
+bsTooltip(
+  id = "KMo",
+  title = "You can examine the change in the KMO value when the items are removed or added.",
+  placement = "bottom",
+  trigger = "hover"
+),
+
+## TITLE PANEL - SIDE BAR PANEL ##
+
+# titlePanel("PRINCIPAL COMPONENT ANALYSIS",
+#   windowTitle = "PRINCIPAL COMPONENT ANALYSIS"
+# ),
+
+# h1(id="title", "PRINCIPAL COMPONENT ANALYSIS"),
+# tags$style(HTML("#title{color: black; font-family: Arial;font-size: 35px;
+#         font-style: oblique;text-align:left}")),
+
+
+
+div(id="tepe",
+    fluidRow(
+
+      column(6,
+
+             h1(id="title", "PRINCIPAL COMPONENT ANALYSIS (PCA) "),
+             tags$style(HTML("#title{color: black; font-family: 'Helvetica Neue', 'Lucida Grande', Helvetica, Arial, sans-serif;;font-size:30px;
+            font-style: oblique;text-align:left}"))
+
+      )  ,
+
+      column(6,
+             h1(id="title2", "RSP PACKAGE  - CRAN"),
+             tags$style(HTML("#title2{color: black; font-family: 'Helvetica Neue', 'Lucida Grande', Helvetica, Arial, sans-serif;;font-size:15px;
+            font-style: oblique;text-align:right}"))
+
+
+
+            # imageOutput("imagex",width = "15%", height = "30px", inline = TRUE),
+
+      )
+
+    )), # close fluidrow
+
+
+
+
+
+br(),
+
+sidebarPanel(
+  ## PANEL 1 - INTRODUCTION ##
+  conditionalPanel(
+    condition = "input.panel==0",
+    shiny::img(src = "img/rsp1.png", width = "97%"),
+    tags$head(
+      tags$script(HTML(js))
+    ),
     br(),
-
-    sidebarPanel(
-      ## PANEL 1 - INTRODUCTION ##
-      conditionalPanel(
-        condition = "input.panel==0",
-        shiny::img(src = "img/rsp1.png", width = "97%"),
-        tags$head(
-          tags$script(HTML(js))
-        ),
-        br(),
-        br(),
-        br(),
-        textOutput("browser"),
-        tags$head(
-          tags$style(
-            "#browser{
+    br(),
+    br(),
+    textOutput("browser"),
+    tags$head(
+      tags$style(
+        "#browser{
                        color: darkblue;
                        font-size: 25px;
                        font-family: cursive;
@@ -181,294 +243,448 @@ $(document).on('shiny:sessioninitialized', function(event) {
                        text-align:center;
                        letter-spacing:1px;
                        }"
-          )
-        ),
-        ######################################################################################
-        # imageOutput("image1",width = "75%", height = "100px", inline = TRUE),
-        ######################################################################################
-      ),
-
-      ## PANEL 2 - DATA UPLOAD ##
-
-      conditionalPanel(
-        condition = "input.panel==1",
-        shiny::img(src = "img/rsp1.png", width = "97%"),
-
-        ###################################################################
-        # imageOutput("image2",width = "15%", height = "50px", inline = TRUE),
-        ###################################################################
-
-
-        radioButtons(
-          "type",
-          h3(id="ab", "Select Data Type"),
-          choices = list("Polytomous (Likert etc..)" = 1, "1-0 " = 2),
-          selected = 1
-        ),
-        selectInput(
-          "type2",
-          h3(id="ab","Select File Format"),
-          choices = list(
-            "CSV - Semicolon  Separated  Excel" = 1,
-            "CSV - Comma  Separated  Excel" = 2,
-            "SAV - SPSS" = 3
-          ),
-          selected = 3
-        ),
-        uiOutput("uiHeader"),
-        fileInput(
-          "data1",
-          h3(id="ab","Uplad Data File")
-        ),
-        gt::gt_output("dat3"),
-        gt::gt_output("dat3.1")
-      ),
-
-      ## PANEL 3 - NUMBER OF FACTORS ##
-      conditionalPanel(
-        condition = "input.panel==2",
-        shiny::img(src = "img/rsp1.png", width = "97%"),
-
-        ###################################################################
-        # imageOutput("image3",width = "15%", height = "50px", inline = TRUE),
-        ###################################################################
-        br(),
-        br(),
-        uiOutput("factornumber"),
-        br(),
-        br(),
-        gt::gt_output("fakor"),
-        br(),
-        br(),
-        selectizeInput(
-          "rotation",
-          h3(id="ab","Select Rotation Method"),
-          choices = list(
-            "Varimax" = "varimax",
-            "Direct Oblimin" = "oblimin",
-            "No Rotation" = "none"
-          ),
-          selected = "none"
-        ),
-      ),
-
-      ## PANEL 4 - FACTOR LOADINGS ##
-      conditionalPanel(
-        condition = "input.panel==3",
-        shiny::img(src = "img/rsp1.png", width = "97%"),
-
-        ###################################################################
-        # imageOutput("image4",width = "15%", height = "50px", inline = TRUE),
-        ###################################################################
-
-
-        br(),
-        br(),
-        br(),
-
-        gt::gt_output("KMo"),
-        br(),
-        br(),
-        uiOutput("remove_item"),
-        br(),
-        br(),
-        uiOutput("select_item"),
-
-        # ##################### NEW KMO 1 #################
-
-        br(),
-        br(),
-
-        sliderInput(
-          "cut_off",
-          h3(id="ab","Select cut-off value for Factor Loadings"),
-          min = 0.25,
-          max = 0.60,
-          step = 0.05,
-          value = 0.30
-        ),
-      ),
-
-      ## PANEL 5 - OUTPUT ##
-
-      conditionalPanel(
-        condition = "input.panel==4",
-        br(),
-        shiny::img(src = "img/rsp1.png", width = "97%"),
-
-        ###################################################################
-        # imageOutput("image5",width = "15%", height = "50px", inline = TRUE),
-        ###################################################################
-        br(),
-
-        shiny::img(src = "img/download.gif", width = "97%"),
-
-        br(),
-        ###################################################################
-        # imageOutput("image6",width = "100%", height = "50px", inline = TRUE),
-        ###################################################################
-
-        # uiOutput("grafmadde")
-      ),
+      )
     ),
-    # close sidebar panel
+    ######################################################################################
+    imageOutput("image1",width = "75%", height = "100px", inline = TRUE),
+    ######################################################################################
 
-    ##  MAIN PANEL ##
+    br(),
+    br(),
 
-    mainPanel(
-      tabsetPanel(
-        id = "panel",
+    shinyWidgets::spectrumInput(   # RENK PALET WİDGET
+      inputId = "myColor",
+      label = "CHANGE THE COLOR OF THE THEME:",
+      choices = list(
+        list('gray', 'white', 'blanchedalmond', 'steelblue', 'forestgreen'),
+        as.list(brewer_pal(palette = "Blues")(9)),
+        as.list(brewer_pal(palette = "Greens")(9)),
+        as.list(brewer_pal(palette = "Spectral")(11)),
+        as.list(brewer_pal(palette = "Dark2")(8))
+      ),
+      options = list(`toggle-palette-more-text` = "Show more")
+    ),
+  ),
 
-        ## MAIN PANEL  1 ##
-        tabPanel(
+  ## PANEL 2 - DATA UPLOAD ##
 
-          # h4("INTRODUCTION"),
+  conditionalPanel(
+    condition = "input.panel==1",
+    shiny::img(src = "img/rsp1.png", width = "97%"),
+
+    ###################################################################
+    imageOutput("image2",width = "15%", height = "50px", inline = TRUE),
+    ###################################################################
+
+    br(),
+    br(),
+
+    shinyWidgets::radioGroupButtons(
+      inputId = "type",
+      label =  h3(id="ab","Select Data Type"),
+      choices = c("Polytomous (Likert etc..)"=1,
+                  "1-0"=2),
+
+      justified = TRUE,
+      checkIcon = list(
+        yes = icon("ok",
+                   lib = "glyphicon")),
+
+      # status = "primary"
+    ),
+
+    shinyWidgets::pickerInput(
+      inputId = "type2",
+      label = h3(id="ab","Select File Format"),
+      choices = list(
+        "CSV - Semicolon  Separated  Excel" = 1,
+        "CSV - Comma  Separated  Excel" = 2,
+        "SAV - SPSS" = 3,
+        "XLSX - Excel"=4
+      ),
+      selected = 3,
+      options =  shinyWidgets::pickerOptions(showTick=TRUE,
+      ),#style = "btn-primary"),
+
+    ),
+
+    uiOutput("uiHeader"),
+
+    div(  style="color:red;",
+
+          HTML( "<marquee direction='left' scrollamount = '5'>
+                      THE DATASET SHOULD CONTAIN ONLY THE VARIABLES TO BE INCLUDED IN THE ANALYSIS!!!
+
+               </marquee>"  )),
+
+    fileInput(
+      "data1",
+      h3(id="ab","Uplad Data File",icon("paper-plane"))
+    ),
+
+    shinyWidgets::dropMenu(
+
+      #actionButton("acb1", "DOWNLOAD"),
 
 
-          h4(id="a", "INTRODUCTION"),
+      padding = "20px",
+
+      theme="light-border",
+
+      placement = "right-end",
 
 
-          value = 0,
-          br(),
-          br(),
-          br(),
+      shinyWidgets::actionBttn(
+        inputId = "acb2",
+        label = "CLICK TO SEE KMO  AND BARTLET SPHERICITY TEST RESULTS",
+        style = "jelly",
+        color = "primary"
 
-          ###################################################################
-          # imageOutput("image0",width = "15%", height = "50px", inline = TRUE),
-          ###################################################################
+      ),
 
-          fluidRow(
-            column(
-              12,
-              align = "center",
-              shiny::img(src = "img/rsp1.png", width = "97%")
-            )
-          )
-        ),
+      gt::gt_output("dat3")
 
-        ##  MAIN PANEL 2 ##
-        tabPanel(
-          # h4( "DATA UPLOAD"),
+    ), # close dropmenu
 
-          h4(id="a", "DATA UPLOAD"),
-          value = 1,
-          textOutput("text1"),
-          tags$head(
-            tags$style(
-              "#text1{
-            color: darkblue;
-            font-size: 25px;
-            font-family: cursive;
-            font-style: oblique;
-            text-align:center;
-            letter-spacing:1px;
-            }"
-            )
-          ),
-          br(),
-          withLoader(
-            DT::dataTableOutput("dat1"),
-            type = "html",
-            loader = "loader1"
-          ),
-          br(),
-          textOutput("text1_1"),
-          tags$head(
-            tags$style(
-              "#text1_1{
-            color: darkblue;
-            font-size: 25px;
-            font-family: cursive;
-            font-style: oblique;
-            text-align:center;
-            letter-spacing:1px;
-            }"
-            )
-          ),
-          br(),
-          gt::gt_output("dat2"),
-          br(),
-          gt::gt_output("dat4"),
-        ),
+    # gt::gt_output("dat3.1")
 
-        ## MAIN PANEL 3 ##
-        tabPanel(
-          # h4("DETERMINING THE NUMBER OF FACTORS"),
+  ),  # close conditional panel
 
-          h4(id="a", "DETERMINING THE NUMBER OF FACTORS"),
+  ## PANEL 3 - NUMBER OF FACTORS ##
+  conditionalPanel(
+    condition = "input.panel==2",
+    shiny::img(src = "img/rsp1.png", width = "97%"),
 
-          value = 2,
-          textOutput("text2"),
-          tags$head(
-            tags$style(
-              "#text2{
-            color: darkblue;
-            font-size: 25px;
-            font-family: cursive;
-            font-style: oblique;
-            text-align:center;
-            letter-spacing:1px;
-            }"
-            )
-          ),
-          br(),
-          br(),
-          withLoader(plotOutput("scree_plot"), type = "html", loader = "loader1"),
-          gt::gt_output("eigen_value"),
-          br()
-        ),
+    ###################################################################
+    imageOutput("image3",width = "15%", height = "50px", inline = TRUE),
+    ###################################################################
+    br(),
+    br(),
 
-        ## MAIN PANEL 4 ##
-        tabPanel(
+    shinyWidgets::chooseSliderSkin("Big", color = "#112446"),
+    uiOutput("factornumber"),
+    br(),
+    br(),
 
-          # h4( "FACTOR LOADINGS AND EXPLAINED VARIANCE"),
+    shinyWidgets::dropMenu(
 
-          h4 (id="a", "FACTOR LOADINGS AND EXPLAINED VARIANCE"),
-          value = 3,
-          textOutput("text2_1"),
-          tags$head(
-            tags$style(
-              "#text2_1{
-            color: darkblue;
-            font-size: 25px;
-            font-family: cursive;
-            font-style: oblique;
-            text-align:center;
-            letter-spacing:1px;
-            }"
-            )
-          ),
-          gt::gt_output("tableFactor"),
-          gt::gt_output("buton"),
-          br(),
-          gt::gt_output("tableEigen"),
-          gt::gt_output("buton2")
-        ),
+      padding = "20px",
 
-        ## MAIN PANEL 5 ##
-        tabPanel(
-          # h4("OUTPUT"),
+      theme="light-border",
+
+      placement = "top-start",
+
+      shinyWidgets::actionBttn(
+        inputId = "korfak",
+        label = "CLICK TO SEE CORRELATIONS AMONG THE FACTORS",
+        style = "jelly",
+        color = "primary"
+
+      ),
+
+      gt::gt_output("fakor"),
 
 
-          h4(id="a", "OUTPUT"),
 
-          value = 4,
-          br(),
-          br(),
 
-          fluidRow(
-            column(4, downloadButton(
-              "factorDownload",
-              h1(id="b",  "DOWNLOAD THE FACTOR LOADINGS"),
-            )),
-            column(8, downloadButton(
-              "varianceDownload",
-              h1(id="b", "DOWNLOAD THE EIGEN VALUES AND EXPLAINED VARIANCE")
-            ))
-          )
+    ),
+
+    br(),
+    br(),
+
+    shinyWidgets::pickerInput(
+      inputId = "rotation",
+      label = h3(id="ab","Select Rotation Method"),
+      choices = list(
+        "Varimax" = "varimax",
+        "Direct Oblimin" = "oblimin",
+        "No Rotation" = "none"
+      ),
+      selected = "none",
+      options =  shinyWidgets::pickerOptions(showTick=TRUE,
+      ),#style = "btn-primary"),
+    ),
+  ),
+
+  ## PANEL 4 - FACTOR LOADINGS ##
+  conditionalPanel(
+    condition = "input.panel==3",
+    shiny::img(src = "img/rsp1.png", width = "97%"),
+
+    ###################################################################
+    imageOutput("image4",width = "15%", height = "50px", inline = TRUE),
+    ###################################################################
+
+    #  br(),
+
+    gt::gt_output("KMo"),
+    br(),
+
+    fluidRow(
+
+      column( 3 ),
+      column( 9,
+
+              uiOutput("remove_item")) ),
+    # br(),
+
+    uiOutput("select_item"),
+
+    # ##################### NEW KMO 1 #################
+
+    br(),
+
+
+    sliderInput(
+      "cut_off",
+      h3(id="ab","Select cut-off value for Factor Loadings"),
+      min = 0.25,
+      max = 0.60,
+      step = 0.05,
+      value = 0.30
+    ),
+
+
+    br(),
+
+    fluidRow(
+
+      column(6,
+
+             shinyWidgets::dropMenu(
+
+               padding = "20px",
+
+               theme="light-border",
+
+               placement = "right-end",
+
+
+               shinyWidgets::actionBttn(
+                 inputId = "coms",
+                 label = "CLICK TO SEE COMMUNALITIES",
+                 style = "jelly",
+                 color = "primary"
+
+               ),
+
+
+               DT::DTOutput("commons"),
+
+             ),
+
+
+      ), # close column
+
+
+
+      column(6,
+
+             shinyWidgets::dropMenu(
+
+               padding = "20px",
+
+               theme="light-border",
+
+               placement = "right-end",
+
+               shinyWidgets::actionBttn(
+                 inputId = "acb1",
+                 label = "CLICK TO  SEE DOWNLOADS",
+                 style = "jelly",
+                 color = "primary"
+
+               ),
+
+
+
+               shinyWidgets::downloadBttn(
+                 "factorDownload",
+                 label = h1(id="b", "FACTOR LOADINGS"),
+                 style = "unite",
+                 color = "primary",
+                 size = "sm",
+                 block = FALSE,
+                 no_outline = TRUE,
+                 icon = shiny::icon("download")
+               ),
+
+               br(),
+               br(),
+
+
+               shinyWidgets::downloadBttn(
+                 "varianceDownload",
+                 label = h1(id="b", " EXPLAINED VARIANCE"),
+                 style = "unite",
+                 color = "primary",
+                 size = "sm",
+                 block = FALSE,
+                 no_outline = TRUE,
+                 icon = shiny::icon("download")
+               ),
+
+
+             ) # close drop menu
+
+
+      ) # close column
+
+    ) # close fluidrow
+
+
+  ), # close conditional panel
+
+), # sidebar panel
+
+##  MAIN PANEL ##
+
+mainPanel(
+  tabsetPanel(
+    id = "panel",
+
+    ## MAIN PANEL  1 ##
+    tabPanel(
+
+      # h4("INTRODUCTION"),
+
+
+      h4(id="a", "INTRODUCTION"),
+
+
+      value = 0,
+      br(),
+      br(),
+      br(),
+
+      ###################################################################
+      imageOutput("image0",width = "15%", height = "50px", inline = TRUE),
+      ###################################################################
+
+      fluidRow(
+        column(
+          12,
+          align = "center",
+          shiny::img(src = "img/rsp1.png", width = "97%")
         )
-      ) # close tabsetpanel
-    ) #  close mainpanel
+      )
+    ),
+
+    ##  MAIN PANEL 2 ##
+    tabPanel(
+      # h4( "DATA UPLOAD"),
+
+      h4(id="a", "DATA UPLOAD"),
+      value = 1,
+      textOutput("text1"),
+      tags$head(
+        tags$style(
+          "#text1{
+            color: darkblue;
+            font-size: 25px;
+            font-family: cursive;
+            font-style: oblique;
+            text-align:center;
+            letter-spacing:1px;
+            }"
+        )
+      ),
+      br(),
+      withLoader(
+        DT::dataTableOutput("dat1"),
+        type = "html",
+        loader = "loader1"
+      ),
+      br(),
+      textOutput("text1_1"),
+      tags$head(
+        tags$style(
+          "#text1_1{
+            color: darkblue;
+            font-size: 25px;
+            font-family: cursive;
+            font-style: oblique;
+            text-align:center;
+            letter-spacing:1px;
+            }"
+        )
+      ),
+      br(),
+      gt::gt_output("dat2"),
+      br(),
+      gt::gt_output("dat4"),
+    ),
+
+    ## MAIN PANEL 3 ##
+    tabPanel(
+      # h4("DETERMINING THE NUMBER OF FACTORS"),
+
+      h4(id="a", "DETERMINING THE NUMBER OF FACTORS"),
+
+      value = 2,
+      textOutput("text2"),
+      tags$head(
+        tags$style(
+          "#text2{
+            color: darkblue;
+            font-size: 25px;
+            font-family: cursive;
+            font-style: oblique;
+            text-align:center;
+            letter-spacing:1px;
+            }"
+        )
+      ),
+      br(),
+      br(),
+      withLoader(plotOutput("scree_plot"), type = "html", loader = "loader1"),
+
+      br(),
+      gt::gt_output("eigen_value"),
+      br()
+    ),
+
+    ## MAIN PANEL 4 ##
+    tabPanel(
+
+      # h4( "FACTOR LOADINGS AND EXPLAINED VARIANCE"),
+
+      h4 (id="a", "FACTOR LOADINGS AND EXPLAINED VARIANCE"),
+      value = 3,
+      textOutput("text2_1"),
+      tags$head(
+        tags$style(
+          "#text2_1{
+            color: darkblue;
+            font-size: 25px;
+            font-family: cursive;
+            font-style: oblique;
+            text-align:center;
+            letter-spacing:1px;
+            }"
+        )
+      ),
+
+      br(),
+
+      gt::gt_output("tableFactor"),
+      gt::gt_output("buton"),
+      br(),
+      gt::gt_output("tableEigen"),
+      gt::gt_output("buton2"),
+      br(),
+
+
+
+
+
+
+
+
+    ),
+
+  ) # close tabsetpanel
+) #  close mainpanel
   ) #  close fluidpage
 
 
@@ -477,7 +693,63 @@ $(document).on('shiny:sessioninitialized', function(event) {
   server <- function(input, output, session) {
 
 
+    #### ALERTS ###
 
+    # observeEvent(input$korfak, {
+    #   show_alert(
+    #     title = "NEXT !!",
+    #     text = "SELECT APPROPRIATE ROTATION METHOD!",
+    #     type = "warning "
+    #   )
+    # })
+    #
+
+    # observeEvent(input$fak2, {
+    #
+    #   req(input$fak2!=1)
+    #
+    #   show_alert(
+    #     title = "NEXT !!",
+    #     text = "CHECK CORRELATIONS AMONG FACTORS!",
+    #     type = "warning ",
+    #     btn_colors = "#3085d6"
+    #   )
+    # })
+
+
+
+
+    # observeEvent(input$rotation, {
+    #
+    #
+    #   req(input$rotation!="none")
+    #
+    #   show_alert(
+    #     title = "GO FOR THE NEXT PANEL!!",
+    #     text = "NOW CHECK THE FACTOR LOADINGS",
+    #     type = "warning "
+    #   )
+    # })
+    #
+
+
+    ######
+
+    shinyjs::addCssClass(class = "bttn bttn-unite bttn-default bttn-no-outline",
+                selector = ".btn-file")
+
+    observeEvent(input$myColor,{
+
+      output$cols<- renderUI({   # WIDET RENDER UI RENK DEĞİŞİMİ
+
+        bbb<-input$myColor
+
+        shinyWidgets::setBackgroundColor(
+          color = c("white", bbb),
+          gradient = "linear",
+          direction = c("bottom", "right")
+        )})
+    })
 
 
     # utils::globalVariables(c("."))
@@ -546,17 +818,26 @@ $(document).on('shiny:sessioninitialized', function(event) {
 
     ###########################################################################
 
+    # observeEvent(input$data1, {
+    #   show_alert(
+    #     title = "Success !!",
+    #     text = "DATA WAS UPLOADED",
+    #     type = "success"
+    #   )
+    # })
 
-
-
+    ###########################################################################
     ##  DATA UPLOAD ##
     output$uiHeader <- renderUI({
       if (input$type2 == 3) {
         NULL
       } else {
-        checkboxInput("header",
-                      "The first line is the variable name",
-                      value = TRUE
+
+        shinyWidgets::materialSwitch(
+          inputId = "header",
+          label =   h4("The first line is the variable name"),
+          value = TRUE,
+          status = "primary"
         )
       }
     })
@@ -565,6 +846,7 @@ $(document).on('shiny:sessioninitialized', function(event) {
       veri <- input$data1
       if (is.null(veri)) {
         return(paste0("PLEASE UPLOAD DATA"))
+
       } else if (input$type2 == 1) {
         if (tools::file_ext(veri$datapath) != "csv") {
           data.frame(warning = "PLEASE SELECT THE CORRECT FILE FORMAT")
@@ -590,9 +872,16 @@ $(document).on('shiny:sessioninitialized', function(event) {
           read.spss(veri$datapath,
                     to.data.frame = TRUE,
                     use.value.labels = FALSE
+          ) }
+      } else if(input$type2==4) {
+        if (tools::file_ext(veri$datapath) != "xlsx") {
+          data.frame(warning = "PLEASE SELECT THE CORRECT FILE FORMAT")
+        } else {
+          xlsx::read.xlsx(veri$datapath, 1, header = isTRUE(input$header)
           )
-        }
-      }
+
+        } }
+
     })
 
     ## WIDGETS FOR UIOUTPUTS ##
@@ -607,6 +896,7 @@ $(document).on('shiny:sessioninitialized', function(event) {
         step = 1,
         value = 1
       )
+
     })
 
     output$select_item <- renderUI({
@@ -622,7 +912,15 @@ $(document).on('shiny:sessioninitialized', function(event) {
     })
 
     output$remove_item <- renderUI({
-      actionButton("remove", h3(id="ab","Remove Selected Item/s"))
+
+
+      shinyWidgets::actionBttn(
+        inputId = "remove",
+        label = "Remove Selected Item/s",
+        style = "jelly",
+        size = "lg",
+        color = "primary", no_outline = TRUE
+      )
     })
 
     ##  TEXTS FOR MAIN PANELS ##
@@ -970,8 +1268,8 @@ $(document).on('shiny:sessioninitialized', function(event) {
             style = gt::cell_text(
               weight = "bolder",
               color = "red",
-              decorate = "underline",
-              stretch = "extra-expanded"
+              decorate = "underline"
+              #stretch = "extra-expanded"
             ),
             locations = gt::cells_body(
               columns = c(EIGENVALUE),
@@ -1001,7 +1299,7 @@ $(document).on('shiny:sessioninitialized', function(event) {
           )
         }
 
-        fac <- model1$r.scores
+        fac <-  round( model1$r.scores,3)
         Row <- paste("Factor", 1:input$fak2)
 
         colnames(fac) <- paste("Factor", 1:input$fak2)
@@ -1061,6 +1359,9 @@ $(document).on('shiny:sessioninitialized', function(event) {
           )
         }
 
+        common<- result$communality
+
+        PCA_ENV$common<-common
 
         eigenvalue <- unname(result$Vaccounted[1, ])
 
@@ -1565,6 +1866,54 @@ $(document).on('shiny:sessioninitialized', function(event) {
       }
     })
 
+
+
+
+
+    #### COMMUNALITIES ###
+
+
+    output$commons<-DT::renderDT({
+
+      data <- na.omit(data())
+
+      if (  length(input$grafmad)==0) {
+
+        data1<-data }  else
+
+
+        {       x<-as.numeric(input$grafmad)
+
+        dat<-as.data.frame(data)
+
+        data1<-dat[,-x]  }
+
+      if (input$type == 1) {
+        cor_matrix <- stats::cor(data1)
+
+        result <- principal(cor_matrix,
+                            nfactors = input$fak2,
+                            rotate = input$rotation
+        )
+      } else {
+        tet_matrix <- tetrachoric(data1)$rho
+
+
+        result <- principal(tet_matrix,
+                            nfactors = input$fak2,
+                            rotate = input$rotation)
+      }
+
+      common<- result$communality
+
+
+      res_comon<- data.frame( Items=paste0("item", 1:ncol(data1)),  Extraction= round(common,3) )
+
+      backgroundColor <- sample(c("tomato1", "turquise", "skyblue",
+                                  "aquamarine", "lightblue", "gray"), 1)
+      datatable(res_comon) %>% formatStyle(colnames(res_comon),
+                                           backgroundColor = backgroundColor) })
+
     ## EXPAINED VARIANCE ##
 
     add <- reactive({
@@ -1718,7 +2067,6 @@ $(document).on('shiny:sessioninitialized', function(event) {
 
         }
 
-
         res <- data.frame(KMO = res)
 
         res <- gt::gt(res)
@@ -2397,15 +2745,12 @@ $(document).on('shiny:sessioninitialized', function(event) {
         }
       }
     )
+
     session$onSessionEnded(function() {
       stopApp()
     })
 
-
-    factor1<-factor2<-factor3<-factor4<-factor5<-factor6<-factor7<-EIGENVALUE<-NULL
-    factorLoading <- factorLoadRemain <- NULL
-    explainedVar <- explainedVarRemain <- NULL
-
+    EIGENVALUE <- factor1 <- factor2 <- factor3 <- factor4 <- factor5 <- factor6 <- factor7 <- NULL
   }
 
   shinyApp(ui = ui, server = server)
